/**
 * A POJO that maps css variables to values
 */
interface VariableDict<T = string> {
    [variable: string]: T;
}
/**
 * Parses strings as css stylesheets to create a reference for their absolute/resolved string values
 *
 * @param {string[]} content List of strings, in order, to parse for variables
 * @param {string} [selector=':root'] A selector to scope the search for variables
 * @returns {{resolved: VariableDict, failed: string[]}} Resolved variables with absolute values + a list of the variables that failed to be resolved.
 */
export default function resolveCssVariables(content: string[], selector?: string): {
    raw: VariableDict;
    resolved: VariableDict;
    failed: string[];
};
export {};
//# sourceMappingURL=index.d.ts.map