"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.resolveFromLookups = exports.parseString = void 0;
var postcss_value_parser_1 = __importDefault(require("postcss-value-parser"));
function parseString(value) {
    return postcss_value_parser_1.default(value).nodes;
}
exports.parseString = parseString;
function isVar(node) {
    return node.type === "function" && node.value === "var";
}
function resolveFromLookups(remaining, resolved, failed, variableName) {
    // for (let variableName in remaining) {
    //   if (resolved[variableName] || failed[variableName]) continue;
    //   resolveFromLookups(remaining, resolved, failed, variableName);
    // }
    if (resolved[variableName] !== null && resolved[variableName] !== undefined) {
        return { type: 'word', value: resolved[variableName] };
    }
    if (failed[variableName]) {
        return null;
    }
    if (remaining[variableName]) {
        var resolvedNode = resolveNodeArray(remaining, resolved, failed, remaining[variableName]);
        if (!resolvedNode) {
            failed[variableName] = true;
            return null;
        }
        resolved[variableName] = resolvedNode.value;
        return resolvedNode;
    }
    return null;
}
exports.resolveFromLookups = resolveFromLookups;
function replaceNodeContentsWith(node, wordNode) {
    node.type = 'word';
    node.value = wordNode.value;
    return node;
}
// need to walk to get to nested 'var' declarations
function resolveNodeArray(remaining, resolved, failed, nodeArray) {
    if (!nodeArray.length)
        return null;
    var terminated = false;
    postcss_value_parser_1.default.walk(nodeArray, function (node) {
        if (terminated)
            return false;
        if (isVar(node)) {
            var variableName = node.nodes[0].value;
            var fallbackNodeArray = node.nodes.slice(2);
            var resolvedValue = resolveFromLookups(remaining, resolved, failed, variableName);
            if (resolvedValue) {
                replaceNodeContentsWith(node, resolvedValue);
            }
            else {
                failed[variableName] = true;
                if (!fallbackNodeArray.length) {
                    terminated = true;
                }
                else {
                    var fallback = resolveNodeArray(remaining, resolved, failed, fallbackNodeArray);
                    if (fallback !== null) {
                        replaceNodeContentsWith(node, fallback);
                    }
                    else {
                        terminated = true;
                    }
                }
            }
            return false;
        }
    });
    if (terminated)
        return null;
    else
        return { type: 'word', value: postcss_value_parser_1.default.stringify(nodeArray) };
}
